==> haskell-cpphs-1.20.8-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.8
id: cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie
key: cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie
license: LicenseRef-LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
author: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
abi: 6b8122bb9d018f7a74e484726cb96122
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
import-dirs: /usr/lib/ghc-8.4.3/site-local/cpphs-1.20.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/cpphs-1.20.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cpphs-1.20.8
hs-libraries: HScpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie
depends:
    base-4.11.1.0 directory-1.3.1.5
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    polyparse-1.12-AafkYPRdYin98WnFInxf9
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             polyparse-1.12-AafkYPRdYin98WnFInxf9=7d1c184e388b294235e7a6e49db40b96
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.8-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.8
id: cpphs-1.20.8-JQMAc3KIkmuHlr2J4Kmw1Y
key: cpphs-1.20.8-JQMAc3KIkmuHlr2J4Kmw1Y
license: LicenseRef-LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
author: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
abi: 8e176bbbf1a641c78438fc21dc05ae92
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
import-dirs: /usr/lib/ghc-8.6.1/site-local/cpphs-1.20.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/cpphs-1.20.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/cpphs-1.20.8
hs-libraries: HScpphs-1.20.8-JQMAc3KIkmuHlr2J4Kmw1Y
depends:
    base-4.12.0.0 directory-1.3.3.0
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4
    polyparse-1.12-1IlNA217wyK1INqBGtVYAy
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
